==> vtwidget_1_0.tar.gz: vtwidget_1_0/ftpterm/lfile_dialog.h <==

/*******************************************************************************
       lfile_dialog.h
       This header file is included by lfile_dialog.c

*******************************************************************************/

#ifndef	_LFILE_DIALOG_INCLUDED
#define	_LFILE_DIALOG_INCLUDED


#include <stdio.h>
#include <Xm/Xm.h>
#include <Xm/MwmUtil.h>
#include <X11/Shell.h>
#include <Xm/MenuShell.h>
#include "UxXt.h"

#include <Xm/FileSB.h>

/*******************************************************************************
       The definition of the context structure:
       If you create multiple copies of your interface, the context
       structure ensures that your callbacks use the variables for the
       correct copy.

       For each swidget in the interface, each argument to the Interface
       function, and each variable in the Interface Specific section of the
       Declarations Editor, there is an entry in the context structure.
       and a #define.  The #define makes the variable name refer to the
       corresponding entry in the context structure.
*******************************************************************************/

typedef	struct
{
	int	mumble;
} _UxClfile_dialog;

#ifdef CONTEXT_MACRO_ACCESS
static _UxClfile_dialog        *UxLfile_dialogContext;

#endif /* CONTEXT_MACRO_ACCESS */

extern Widget	lfile_dialog;

/*******************************************************************************
       Declarations of global functions.
*******************************************************************************/

Widget	create_lfile_dialog();

#endif	/* _LFILE_DIALOG_INCLUDED */

==> vtwidget-1.3.tar.gz: vtwidget-1.3/ftpterm/lfile_dialog.h <==

/*******************************************************************************
       lfile_dialog.h
       This header file is included by lfile_dialog.c

*******************************************************************************/

#ifndef	_LFILE_DIALOG_INCLUDED
#define	_LFILE_DIALOG_INCLUDED

#include <stdio.h>

#ifdef MOTIF
#include <Xm/Xm.h>
#include <Xm/MwmUtil.h>
#include <X11/Shell.h>
#include <Xm/MenuShell.h>
#endif /* MOTIF */

#include "UxXt.h"

#ifndef XKLOADDS
#define XKLOADDS
#endif /* XKLOADDS */

/*******************************************************************************
       The definition of the context structure:
       If you create multiple copies of your interface, the context
       structure ensures that your callbacks use the variables for the
       correct copy.

       For each swidget in the interface, each argument to the Interface
       function, and each variable in the Interface Specific section of the
       Declarations Editor, there is an entry in the context structure
       and a #define.  The #define makes the variable name refer to the
       corresponding entry in the context structure.
*******************************************************************************/

typedef	struct
{
	int	mumble;
} _UxClfile_dialog;

#ifdef CONTEXT_MACRO_ACCESS
static _UxClfile_dialog        *UxLfile_dialogContext;

#endif /* CONTEXT_MACRO_ACCESS */

extern Widget	lfile_dialog;

/*******************************************************************************
       Declarations of global functions.
*******************************************************************************/

Widget	create_lfile_dialog( void );

#endif	/* _LFILE_DIALOG_INCLUDED */
